"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configService = void 0;
require('dotenv').config();
class ConfigService {
    constructor(env) {
        this.env = env;
    }
    getValue(key, throwOnMissing = true) {
        const value = this.env[key];
        if (!value && throwOnMissing) {
            throw new Error(`config error - missing env.${key}`);
        }
        return value;
    }
    ensureValues(keys) {
        keys.forEach(k => this.getValue(k, true));
        return this;
    }
    getPort() {
        return this.getValue('PORT', true);
    }
    isProduction() {
        const mode = this.getValue('MODE', false);
        return mode != 'DEV';
    }
    getTypeOrmConfig() {
        return {
            type: 'mongodb',
            host: this.getValue('MONGODB_HOST'),
            port: parseInt(this.getValue('MONGODB_PORT')),
            database: this.getValue('MONGODB_DATABASE'),
            ssl: this.isProduction(),
            entities: [
                __dirname + '/../**/*.entity{.ts,.js}',
            ],
            synchronize: false
        };
    }
}
const configService = new ConfigService(process.env)
    .ensureValues([
    'MONGODB_HOST',
    'MONGODB_PORT',
    'MONGODB_DATABASE'
]);
exports.configService = configService;
